==> stackdidact-1.0.1.tar.gz: stackdidact-1.0.1/README.md <==
# stackdidact
Fresh Questions from Stack Exchange family for those who want to learn something new **often**.

## What is `stackdidact` ?
`stackdidact` is primarily supposed to be a shell command to generate a question from [StackOverflow](http://stackoverflow.com) (and the [StackExchange](http://stackexchange.com/sites) family, in general).
The interesting part is that each time this a **new** question is displayed.   

## Motivation for `stackdidact` ?

One basically has to be an autodidact to learn programming. It takes a lot of practice to learn everything necessary to learn the deeper aspects of programming. No one has ever become a great programmer just by taking classes or reading books. It takes hours of practice and persistence.

To this end, in order to expand my programming knowledge, I started reading popular(highly voted) questions on StackOverflow pertaining to certain "tags" (`python` being my favourite) in my spare time. This was a habit which I developed the Summers of 2016. However, I had been lacking this enthusiasm lately; primarily due to my procrastination. Hence, I created `stackdidact` to throw at me a random question to motivate me.

If you relate to this problem, I hope `stackdidact` will be of use to you.
Also, if you are an "autodidact" programmer or atleast aspire to be one, this command is for you !

## Installation: Adding the `stackdidact` shell command
- Clone this project locally : `$ git clone https://github.com/kshitij10496/stackdidact.git`
- Export the `cmd.py` using the `stackdiadact` alias either by adding the line below to your `.bashrc` or `.bash_aliases`:
`alias stackdidact="python3 path/to/stackdidact/cmd.py"`
- Restart your terminal emulator or start a new shell.
- Type `stackdidact`.

![Preview Image](https://github.com/kshitij10496/stackdidact/blob/master/preview.png)
If you face any issues with the installation, discuss it by creating an issue.

## Contributing
If you have got any suggestions for new features or improvements, feel free to create an issue about it [here](https://github.com/kshitij10496/stackdidact/issues).
I will try to work to them. Better yet, Pull Requests are welcome.

==> stackdidact-1.1.0.tar.gz: stackdidact-1.1.0/README.md <==
# stackdidact
Fresh Questions from Stack Exchange family for those who want to learn something new **often**.

## What is `stackdidact` ?
`stackdidact` is primarily supposed to be a shell command to generate a question from [StackOverflow](http://stackoverflow.com) (and the [StackExchange](http://stackexchange.com/sites) family, in general).
The interesting part is that each time this a **new** question is displayed.   

## Why `stackdidact` ?

One basically has to be an autodidact to learn programming. It takes a lot of practice to learn everything necessary to learn the deeper aspects of programming. No one has ever become a great programmer just by taking classes or reading books. It takes hours of practice and persistence.

To this end, in order to expand my programming knowledge, I started reading popular(highly voted) questions on StackOverflow pertaining to certain "tags" (`python` being my favourite) in my spare time. This was a habit which I developed the Summers of 2016. However, I had been lacking this enthusiasm lately; primarily due to my procrastination. Hence, I created `stackdidact` to throw at me a random question to motivate me.

If you relate to this problem, I hope `stackdidact` will be of use to you.
Also, if you are an "autodidact" programmer or atleast aspire to be one, this command is for you !

## Installation

`stackdidact` is available on PyPi and can be installed through Python's package manager `pip` as:

`$ pip3 install stackdidact` 

NOTE: Linux users need to use `sudo` for installing the package systemwide.

![Preview Image](https://github.com/kshitij10496/stackdidact/blob/master/preview.png)
If you face any issues with the installation, discuss it by creating an issue.

## Contributing
If you have got any suggestions for new features or improvements, feel free to create an issue about it [here](https://github.com/kshitij10496/stackdidact/issues).
I will try to work to them. Better yet, Pull Requests are welcome.
